// generated from rosidl_adapter/resource/msg.idl.em
// with input from rcl_interfaces/msg/LoggerLevel.msg
// generated code does not contain a copyright notice


module rcl_interfaces {
  module msg {
    module LoggerLevel_Constants {
      const uint8 LOG_LEVEL_UNKNOWN = 0;
      const uint8 LOG_LEVEL_DEBUG = 10;
      const uint8 LOG_LEVEL_INFO = 20;
      const uint8 LOG_LEVEL_WARN = 30;
      const uint8 LOG_LEVEL_ERROR = 40;
      const uint8 LOG_LEVEL_FATAL = 50;
    };
    @verbatim (language="comment", text=
      "All available logger levels; these correspond to the enum in rcutils/logger.h")
    struct LoggerLevel {
      @verbatim (language="comment", text=
        "The logger name.")
      string name;

      @verbatim (language="comment", text=
        "The logger level")
      uint32 level;
    };
  };
};
