// generated from rosidl_generator_c/resource/idl.h.em
// with input from rcl_interfaces:msg/SetParametersResult.idl
// generated code does not contain a copyright notice

#ifndef RCL_INTERFACES__MSG__SET_PARAMETERS_RESULT_H_
#define RCL_INTERFACES__MSG__SET_PARAMETERS_RESULT_H_

#include "rcl_interfaces/msg/detail/set_parameters_result__struct.h"
#include "rcl_interfaces/msg/detail/set_parameters_result__functions.h"
#include "rcl_interfaces/msg/detail/set_parameters_result__type_support.h"

#endif  // RCL_INTERFACES__MSG__SET_PARAMETERS_RESULT_H_
