// generated from rosidl_adapter/resource/msg.idl.em
// with input from rcl_interfaces/msg/SetLoggerLevelsResult.msg
// generated code does not contain a copyright notice


module rcl_interfaces {
  module msg {
    @verbatim (language="comment", text=
      "True when succeed, false when failed.")
    struct SetLoggerLevelsResult {
      boolean successful;

      @verbatim (language="comment", text=
        "Reason why the setting was either successful or a failure.")
      string reason;
    };
  };
};
